==> dojo-1.9.4.tgz: package/cldr/nls/pt/buddhist.js <==
define(
//begin v1.x content
{
	"field-dayperiod": "Período do dia",
	"dateFormatItem-yyyyMMMEd": "E, d 'de' MMM 'de' y G",
	"field-minute": "Minuto",
	"dateFormatItem-MMMEd": "E, d 'de' MMM",
	"field-day-relative+-1": "Ontem",
	"field-weekday": "Dia da semana",
	"field-day-relative+-2": "Anteontem",
	"days-standAlone-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-era": "Era",
	"dateFormatItem-Gy": "y G",
	"field-hour": "Hora",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dateFormatItem-y": "y G",
	"dateFormatItem-yyyy": "y G",
	"months-standAlone-abbr": [
		"jan",
		"fev",
		"mar",
		"abr",
		"mai",
		"jun",
		"jul",
		"ago",
		"set",
		"out",
		"nov",
		"dez"
	],
	"dateFormatItem-Ed": "E, d",
	"field-day-relative+0": "Hoje",
	"field-day-relative+1": "Amanhã",
	"days-standAlone-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"eraAbbr": [
		"BE"
	],
	"field-day-relative+2": "Depois de amanhã",
	"dateFormatItem-GyMMMd": "d 'de' MMM 'de' y G",
	"dateFormat-long": "d 'de' MMMM 'de' y G",
	"field-zone": "Fuso",
	"field-week-relative+-1": "Semana passada",
	"dateFormat-medium": "dd/MM/y G",
	"dayPeriods-format-narrow-pm": "p",
	"field-year-relative+0": "Este ano",
	"field-year-relative+1": "Próximo ano",
	"quarters-standAlone-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"field-year-relative+-1": "Ano passado",
	"field-year": "Ano",
	"dayPeriods-format-narrow-am": "a",
	"field-week": "Semana",
	"months-standAlone-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"dateFormatItem-yyyyMMMd": "d 'de' MMM 'de' y G",
	"dateFormatItem-yyyyMd": "dd/MM/y GGGGG",
	"dateFormatItem-yyyyMEd": "E, dd/MM/y GGGGG",
	"field-week-relative+0": "Esta semana",
	"dateFormatItem-MMMd": "d 'de' MMM",
	"field-week-relative+1": "Próxima semana",
	"months-format-abbr": [
		"jan",
		"fev",
		"mar",
		"abr",
		"mai",
		"jun",
		"jul",
		"ago",
		"set",
		"out",
		"nov",
		"dez"
	],
	"field-month-relative+0": "Este mês",
	"field-month": "Mês",
	"field-month-relative+1": "Próximo mês",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"days-format-abbr": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"days-format-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"field-second": "Segundo",
	"dateFormatItem-GyMMMEd": "E, d 'de' MMM 'de' y G",
	"dateFormatItem-GyMMM": "MMM 'de' y G",
	"field-day": "Dia",
	"dateFormatItem-MEd": "E, dd/MM",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"days-standAlone-short": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"days-standAlone-abbr": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"dateFormat-short": "dd/MM/yy GGGGG",
	"dateFormatItem-yyyyM": "MM/y GGGGG",
	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y G",
	"dateFormatItem-Md": "d/M",
	"months-format-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"days-format-short": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"dateFormatItem-yyyyMMM": "MMM 'de' y G",
	"field-month-relative+-1": "Mês passado",
	"quarters-format-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"days-format-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	]
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/pt/buddhist.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "agora",
	"field-weekday": "Dia da semana",
	"field-wed-relative+0": "esta quarta-feira",
	"field-wed-relative+1": "próxima quarta-feira",
	"dateFormatItem-GyMMMEd": "E, d 'de' MMM 'de' y G",
	"dateFormatItem-MMMEd": "E, d 'de' MMM",
	"field-tue-relative+-1": "terça-feira passada",
	"days-format-short": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"dateFormat-long": "d 'de' MMMM 'de' y G",
	"field-fri-relative+-1": "sexta-feira passada",
	"field-wed-relative+-1": "quarta-feira passada",
	"months-format-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y G",
	"dateFormatItem-yyyyMEd": "E, dd/MM/y GGGGG",
	"field-thu-relative+-1": "quinta-feira passada",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-wide-noon": "meio-dia",
	"field-era": "Era",
	"months-standAlone-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"quarters-format-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"field-year": "Ano",
	"field-hour": "Hora",
	"months-format-abbr": [
		"jan",
		"fev",
		"mar",
		"abr",
		"mai",
		"jun",
		"jul",
		"ago",
		"set",
		"out",
		"nov",
		"dez"
	],
	"field-sat-relative+0": "este sábado",
	"field-sat-relative+1": "próximo sábado",
	"field-day-relative+0": "hoje",
	"field-thu-relative+0": "esta quinta-feira",
	"field-day-relative+1": "amanhã",
	"field-thu-relative+1": "próxima quinta-feira",
	"dateFormatItem-GyMMMd": "d 'de' MMM 'de' y G",
	"field-day-relative+2": "depois de amanhã",
	"months-standAlone-abbr": [
		"jan",
		"fev",
		"mar",
		"abr",
		"mai",
		"jun",
		"jul",
		"ago",
		"set",
		"out",
		"nov",
		"dez"
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-standAlone-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d 'de' MMM 'de' y G",
	"days-standAlone-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"dateFormatItem-yyyyMMM": "MMM 'de' y G",
	"dateFormatItem-yyyyMMMd": "d 'de' MMM 'de' y G",
	"field-sun-relative+0": "este domingo",
	"field-sun-relative+1": "próximo domingo",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"eraAbbr": [
		"BE"
	],
	"field-minute": "Minuto",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"field-day-relative+-1": "ontem",
	"field-day-relative+-2": "anteontem",
	"dateFormatItem-MMMd": "d 'de' MMM",
	"dateFormatItem-MEd": "E, dd/MM",
	"field-fri-relative+0": "esta sexta-feira",
	"field-fri-relative+1": "próxima sexta-feira",
	"field-day": "Dia",
	"days-format-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"field-zone": "Fuso horário",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "ano passado",
	"field-month-relative+-1": "mês passado",
	"days-format-abbr": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"days-format-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"dateFormatItem-yyyyMd": "dd/MM/y GGGGG",
	"field-month": "Mês",
	"days-standAlone-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"field-tue-relative+0": "esta terça-feira",
	"field-tue-relative+1": "próxima terça-feira",
	"field-mon-relative+0": "esta segunda-feira",
	"field-mon-relative+1": "próxima segunda-feira",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"field-second": "Segundo",
	"field-sat-relative+-1": "sábado passado",
	"field-sun-relative+-1": "domingo passado",
	"field-month-relative+0": "este mês",
	"field-month-relative+1": "próximo mês",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Semana",
	"dateFormat-medium": "dd/MM/y G",
	"field-year-relative+0": "este ano",
	"field-week-relative+-1": "semana passada",
	"dateFormatItem-yyyyM": "MM/y GGGGG",
	"field-year-relative+1": "próximo ano",
	"dateFormatItem-GyMMM": "MMM 'de' y G",
	"field-mon-relative+-1": "segunda-feira passada",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "esta semana",
	"field-week-relative+1": "próxima semana"
}
//end v1.x content
);
